'''This is a module of the library PCPyLib for plotting Pedal Curves.'''

from .basic import PC
import matplotlib.pyplot as plt

def plot(n, fx_str2, px2, py2):
    '''This is a function for plotting pedal curves. 

       Parameters
       ----------
       n : num of the figure\n
       fx_str2 : str\n
       px2, py2 : num

       Returns
       -------
       the figure'''
    fig = plt.figure(n, figsize=(5, 2))
    p = PC(fx_str2, px2, py2)
    ax1 = fig.add_subplot(1, 2, 1)
    ax1.plot(p.a, p.b)
    ax2 = fig.add_subplot(1, 2, 2)
    ax2.plot(p.x, p.y)
## texts ##
    plt.rc('mathtext', fontset='stix')
    ax1.text(1, 1, r'$y = {}$'.format(fx_str2), fontsize=15, ha='right', 
             va='top', transform=ax1.transAxes)
    ax2.text(1, 1, r'${}$'.format("Pedal Curves"), fontsize=10, ha='right', 
             va='top', transform=ax2.transAxes)
    ax2.text(1, 0.9, r'$Px = {}$'.format(px2), fontsize=10, ha='right', 
             va='top', transform=ax2.transAxes)
    ax2.text(1, 0.8, r'$Py = {}$'.format(py2),fontsize=10, ha='right', 
             va='top', transform=ax2.transAxes)
    fig.show()
    return




'''This is a module of the library PCPyLib for animating Pedal Curves.'''

from .basic import PC
import matplotlib.pyplot as plt
from matplotlib.animation import FuncAnimation

def anim(n, fx_str3):
    '''This is a function for animating pedal curves. 

       Parameters
       ----------
       n : num of the figure\n
       fx_str3 : str
       
       Returns
       -------
       the figure'''
    dt = 1/15
    fig = plt.figure(n, figsize=(15, 5))
    ax = fig.add_subplot(111)
    fig.subplots_adjust(bottom=0.2)
    ax.set_xlabel('x')
    ax.set_ylabel('y')
    def animate(i):
        plt.clf()
        t = float(i)*dt
        lim = t - 30
        p = PC(fx_str3, lim, lim)
        ax.set_xlim(lim-50, lim+50)
        ax.set_ylim(lim-0.3, lim+0.3)
        line, = ax.plot(p.x, p.y, color='C0')
        return line,
    ani = FuncAnimation(fig, func=animate, frames=range(720), interval=dt, 
                        blit=True)
    fig.show()
    return


'''This is a module of the library PCPyLib for basic things:\n
   deriv(func), PC(class)'''
   
from numpy import (linspace, sin, cos, tan, sinh, cosh, tanh, arcsin, arccos, 
                   arctan, arcsinh, arccosh, arctanh, degrees, radians, sqrt,
                   log10, round, floor, ceil, sign, exp, log)
from scipy.special import gamma, erf

def deriv(f0, x, h=0.01):
    '''This is the derivative of a function.
    
       Parameters
       ----------
       f0(func), x(num), h(*kwargs)
       
       Returns
       -------
       the derivative of the function'''
    return (f0(x + h) - f0(x - h))/(2*h)
class PC():
    '''
    PC
    ==
    This is a class of the calculation of pedal curves.\n
    Parameters
    ----------
    fx_str1(str), px1, py1(x, y of the point)
    
    Returns
    -------
    a, b: x, y of the function\n
    x, y: x, y of pedal curves'''
    def __init__(self, fx_str1, px1, py1):
        self.a = linspace(-5, 5, 10000)
        def f(x):
            return eval(fx_str1)
        self.b = f(self.a)
        d = deriv(f, self.a)
        self.x = (self.a*d**2 + d*(py1 - self.b) + px1)/(d**2 + 1)
        self.y = (py1*d**2 + self.b + px1 - self.a)/(d**2 + 1)
        return


'''
pclab4
======

A Python Library of pedal curves.

How to use
----------
We recommend you to import `pclab4`:\n
  >>> import pclab4
  >>> pclab4.deriv(lambda x: x**3, 2)
  12.000099999999847
  
Use the built-in ``help`` function to view a function's docstring:\n
  >>> help(pclab4.deriv)
  ... # doctest: +SKIP
  
Viewing documentation using IPython
-----------------------------------
To see which functions are available in `pclab4`, type ``pclab4.<TAB>`` (where
``<TAB>`` refers to the TAB key), or use ``pclab4.*deriv*?<ENTER>`` (where 
``<ENTER>`` refers to the ENTER key) to narrow down the list.  To view the 
docstring for a function, use ``pclab4.deriv?<ENTER>`` (to view the docstring) 
and ``pclab4.deriv??<ENTER>`` (to view the source code).

We recommend exploring the docstrings using `IPython <https://ipython.org>`_, 
an advanced Python shell with TAB-completion and introspection capabilities. 
See above for further instructions.
  
Click `pclab4 Homepage <https://pypi.org/project/pclab4/>`_ to explore.'''
from .basic import deriv, PC
from .pcplot import plot
from .pcanim import anim
from .install import my_setup, myinfo

__version__ = '4.0.2'


from setuptools import setup, find_packages

myinfo={'author': 'S_My',
        'email': 'mingyang3sun@hotmail.com',
        'copyright':'Copyright (c) 2025-2026, S_My Programming Team & '\
                    'KitPy Developers'}

def confirm_info(all_modules):
    '''Confirm name, version of a module.'''
    name = all_modules.__name__
    version = all_modules.__version__
    return name, version
    
def pkg_setup(package, **attrs):
    '''packages' setup. Need version string(__version__).\n
       **attrs: except `name`, `version` and `packages`.'''
    _name, _version= confirm_info(package)
    setup(name=_name, packages=find_packages(), version=_version, **attrs)
    
def my_setup(pkg, **attrs):
    '''S_My setup tools.'''
    pkg_setup(pkg, 
              classifiers = ['Operating System :: Microsoft :: Windows :: Windows 11',
                             'Programming Language :: Python :: 3',
                             'Programming Language :: Python :: 3.9',
                             'License :: OSI Approved :: MIT License',],
              long_description = pkg.__doc__,
              long_description_content_type='text/x-rst',
              license=f"MIT License({myinfo['copyright']})",
              author=myinfo['author'],
              author_email=myinfo['email'],
              **attrs)



import pclab4

pclab4.my_setup(pclab4,
      install_requires=["numpy>=1.26.4",
                        "matplotlib>=3.9.2",
                        "scipy>=1.13.1",],
      description='Pedal Curves Lab Version 4',
      python_requires='>=3.9',
      url='https://pypi.org/project/pclab4/'
      )